# Lee-Carter Model

## Brief
Lee-Carter Model is a statistical model dedicated to mortality rate or life expectancy forecasting. The original paper can be found here [here](http://pagesperso.univ-brest.fr/~ailliot/doc_cours/M1EURIA/regression/leecarter.pdf).
